@@ -45,11 +45,21 @@ static void AddFilesToList(const std::string& FileList, std::vector<std::string>
     // xml is a bonus then, since we can easily extend it
     // we need a good parser then -> suggestion : TinyXml
     // drawback : creates a dependency
-    std::ifstream Files(FileList.c_str());
+    std::istream *Files;
+    std::ifstream Infile;
+    if (FileList.compare("-") == 0) // read from stdin
+    {
+        Files = &std::cin;
+    }
+    else
+    {
+        Infile.open(FileList.c_str());
+        Files = &Infile;
+    }
     if (Files)
     {
         std::string FileName;
-        while (std::getline(Files, FileName)) // next line
+        while (std::getline(*Files, FileName)) // next line
         {
             if (!FileName.empty())
             {
@@ -83,6 +93,7 @@ bool CmdLineParser::ParseFromArgs(int argc, const char* const argv[])
             _exitAfterPrint = true;
             return true;
         }
+
         // Flag used for various purposes during debugging
         else if (strcmp(argv[i], "--debug") == 0)
             _settings->debug = _settings->debugwarnings = true;
@@ -91,6 +102,10 @@ bool CmdLineParser::ParseFromArgs(int argc, const char* const argv[])
         else if (strcmp(argv[i], "--debug-warnings") == 0)
             _settings->debugwarnings = true;
 
+        // Print out code that triggers false positive
+        else if (strcmp(argv[i], "--debug-fp") == 0)
+            _settings->debugFalsePositive = true;
+
         // Enable all checks - will be removed in future
         else if (strcmp(argv[i], "-a") == 0 || strcmp(argv[i], "--all") == 0)
         {
@@ -275,6 +290,12 @@ bool CmdLineParser::ParseFromArgs(int argc, const char* const argv[])
                 PrintMessage(errmsg);
                 return false;
             }
+            // when "style" is enabled, also enable "performance" and "portability"
+            else if (strstr(argv[i]+9, "style"))
+            {
+                _settings->addEnabled("performance");
+                _settings->addEnabled("portability");
+            }
         }
 
         // --error-exitcode=1
@@ -404,6 +425,18 @@ bool CmdLineParser::ParseFromArgs(int argc, const char* const argv[])
             _settings->reportProgress = true;
         }
 
+        // --std
+        else if (strcmp(argv[i], "--std=posix") == 0)
+        {
+            _settings->posix = true;
+        }
+
+        // --C99
+        else if (strcmp(argv[i], "--std=c99") == 0)
+        {
+            _settings->c99 = true;
+        }
+
         // Output formatter
         else if (strcmp(argv[i], "--template") == 0)
         {
@@ -574,6 +607,31 @@ bool CmdLineParser::ParseFromArgs(int argc, const char* const argv[])
             _settings->checkConfiguration = true;
         }
 
+        // Specify platform
+        else if (strncmp(argv[i], "--platform=", 11) == 0)
+        {
+            std::string platform(11+argv[i]);
+
+            if (platform == "win32A")
+                _settings->platform(Settings::Win32A);
+            else if (platform == "win32W")
+                _settings->platform(Settings::Win32W);
+            else if (platform == "win64")
+                _settings->platform(Settings::Win64);
+            else if (platform == "unix32")
+                _settings->platform(Settings::Unix32);
+            else if (platform == "unix64")
+                _settings->platform(Settings::Unix64);
+            else
+            {
+                std::string message("cppcheck: error: unrecognized platform\"");
+                message += argv[i];
+                message +=  "\"";
+                PrintMessage(message);
+                return false;
+            }
+        }
+
         // Print help
         else if (strcmp(argv[i], "-h") == 0 || strcmp(argv[i], "--help") == 0)
         {
@@ -652,7 +710,13 @@ void CmdLineParser::PrintHelp()
               "                          * all\n"
               "                                  Enable all checks\n"
               "                          * style\n"
-              "                                  Check coding style\n"
+              "                                  Enable all coding style checks. All messages\n"
+              "                                  with the severities 'style', 'performance'\n"
+              "                                  and 'portability' are enabled.\n"
+              "                          * performance\n"
+              "                                  Enable performance messages\n"
+              "                          * portability\n"
+              "                                  Enable portability messages\n"
               "                          * information\n"
               "                                  Enable information messages\n"
               "                          * unusedFunction\n"
@@ -672,7 +736,8 @@ void CmdLineParser::PrintHelp()
               "                         Used when certain messages should be displayed but\n"
               "                         should not cause a non-zero exitcode.\n"
               "    --file-list=<file>   Specify the files to check in a text file. Add one\n"
-              "                         filename per line.\n"
+              "                         filename per line. When file is -, the file list will\n"
+              "                         be read from standard input.\n"
               "    -f, --force          Force checking of all configurations in files that have\n"
               "                         \"too many\" configurations.\n"
               "    -h, --help           Print this help.\n"
@@ -687,6 +752,18 @@ void CmdLineParser::PrintHelp()
               "                         more comments, like: // cppcheck-suppress warningId\n"
               "                         on the lines before the warning to suppress.\n"
               "    -j <jobs>            Start [jobs] threads to do the checking simultaneously.\n"
+              "    --platform=<type>    Specifies platform specific types and sizes. The\n"
+              "                         available platforms are:\n"
+              "                          * unix32\n"
+              "                                 32 bit unix variant\n"
+              "                          * unix64\n"
+              "                                 64 bit unix variant\n"
+              "                          * win32A\n"
+              "                                 32 bit Windows ASCII character encoding\n"
+              "                          * win32W\n"
+              "                                 32 bit Windows UNICODE character encoding\n"
+              "                          * win64\n"
+              "                                 64 bit Windows\n"
               "    -q, --quiet          Only print error messages.\n"
               "    --report-progress    Report progress messages while checking a file.\n"
 #ifdef HAVE_RULES
@@ -695,6 +772,8 @@ void CmdLineParser::PrintHelp()
               "                         https://sourceforge.net/projects/cppcheck/files/Articles/\n"
 #endif
               "    -s, --style          Deprecated, use --enable=style\n"
+              "    --std=posix          Code is posix\n"
+              "    --std=c99            Code is C99 standard\n"
               "    --suppress=<spec>    Suppress warnings that match <spec>. The format of\n"
               "                         <spec> is:\n"
               "                         [error id]:[filename]:[line]\n"
