@@ -33,11 +33,9 @@ static int tolowerWrapper(int c)
 
 bool FileLister::acceptFile(const std::string &filename)
 {
-    std::string::size_type dotLocation = filename.find_last_of('.');
-    if (dotLocation == std::string::npos)
+    std::string extension = Path::getFilenameExtension(filename);
+    if (extension == "")
         return false;
-
-    std::string extension = filename.substr(dotLocation);
     std::transform(extension.begin(), extension.end(), extension.begin(), tolowerWrapper);
 
     if (extension == ".cpp" ||
@@ -109,6 +107,15 @@ static HANDLE MyFindFirstFile(std::string path, LPWIN32_FIND_DATA findData)
     return hFind;
 }
 
+static BOOL MyFileExists(std::string path)
+{
+    WCHAR * unicodeOss = new wchar_t[path.size() + 1];
+    TransformAnsiToUcs2(path.c_str(), unicodeOss, (path.size() + 1) * sizeof(WCHAR));
+    BOOL result = PathFileExists(unicodeOss);
+    delete [] unicodeOss;
+    return result;
+}
+
 #else // defined(UNICODE)
 
 static BOOL MyIsDirectory(std::string path)
@@ -127,6 +134,12 @@ static HANDLE MyFindFirstFile(std::string path, LPWIN32_FIND_DATA findData)
     return hFind;
 }
 
+static BOOL MyFileExists(std::string path)
+{
+    BOOL result = PathFileExists(path.c_str());
+    return result;
+}
+
 #endif // defined(UNICODE)
 
 void FileLister::recursiveAddFiles(std::vector<std::string> &filenames, std::map<std::string, long> &filesizes, const std::string &path)
@@ -228,7 +241,13 @@ bool FileLister::isDirectory(const std::string &path)
     return (MyIsDirectory(path) != FALSE);
 }
 
-
+bool FileLister::fileExists(const std::string &path)
+{
+    if (MyFileExists(path) == TRUE)
+        return true;
+    else
+        return false;
+}
 
 
 #else
@@ -335,4 +354,22 @@ bool FileLister::isDirectory(const std::string &path)
     return ret;
 }
 
+bool FileLister::fileExists(const std::string &path)
+{
+    struct stat statinfo;
+    int result = stat(path.c_str(), &statinfo);
+
+    if (result < 0)  // Todo: should check errno == ENOENT?
+    {
+        // File not found
+        return false;
+    }
+
+    // Check if file is regular file
+    if ((statinfo.st_mode & S_IFMT) == S_IFREG)
+        return true;
+
+    return false;
+}
+
 #endif
