@@ -145,8 +145,35 @@ MainWindow::MainWindow() :
         connect(mRecentProjectActs[i], SIGNAL(triggered()),
                 this, SLOT(OpenRecentProject()));
     }
+    mRecentProjectActs[MaxRecentProjects] = NULL; // The separator
     mUI.mActionProjectMRU->setVisible(false);
     UpdateMRUMenuItems();
+
+    QActionGroup* platformGroup = new QActionGroup(this);
+    for (int i = 0; i < mPlatforms.getCount(); i++)
+    {
+        Platform plat = mPlatforms.mPlatforms[i];
+        QAction *act = new QAction(this);
+        plat.mActMainWindow = act;
+        mPlatforms.mPlatforms[i] = plat;
+        act->setText(plat.mTitle);
+        act->setData(plat.mType);
+        act->setCheckable(true);
+        act->setActionGroup(platformGroup);
+        mUI.mMenuCheck->insertAction(mUI.mActionPlatforms, act);
+        connect(act, SIGNAL(triggered()), this, SLOT(SelectPlatform()));
+    }
+
+    // For Windows platforms default to Win32 checked platform.
+    // For other platforms default to unspecified/default which means the
+    // platform Cppcheck GUI was compiled on.
+#if defined(_WIN32)
+    Platform &plat = mPlatforms.get(Settings::Win32A);
+#else
+    Platform &plat = mPlatforms.get(Settings::Unspecified);
+#endif
+    plat.mActMainWindow->setChecked(true);
+    mSettings->setValue(SETTINGS_CHECKED_PLATFORM, plat.mType);
 }
 
 MainWindow::~MainWindow()
@@ -192,7 +219,11 @@ void MainWindow::LoadSettings()
     mUI.mActionShowInformation->setChecked(mSettings->value(SETTINGS_SHOW_INFORMATION, true).toBool());
 
     mUI.mResults->ShowResults(SHOW_ERRORS, mUI.mActionShowErrors->isChecked());
+    mUI.mResults->ShowResults(SHOW_WARNINGS, mUI.mActionShowWarnings->isChecked());
     mUI.mResults->ShowResults(SHOW_STYLE, mUI.mActionShowStyle->isChecked());
+    mUI.mResults->ShowResults(SHOW_PORTABILITY, mUI.mActionShowPortability->isChecked());
+    mUI.mResults->ShowResults(SHOW_PERFORMANCE, mUI.mActionShowPerformance->isChecked());
+    mUI.mResults->ShowResults(SHOW_INFORMATION, mUI.mActionShowInformation->isChecked());
 
     // Main window settings
     const bool showMainToolbar = mSettings->value(SETTINGS_TOOLBARS_MAIN_SHOW, true).toBool();
@@ -212,10 +243,10 @@ void MainWindow::LoadSettings()
     bool succeeded = mApplications->LoadSettings();
     if (!succeeded)
     {
-        QString msg = tr("There was a problem with loading the editor application settings.\n\n"
-                         "This is probably because the settings were changed between the Cppcheck versions. "
-                         "Please check (and fix) the editor application settings, otherwise the editor "
-                         "program might not start correctly.");
+        const QString msg = tr("There was a problem with loading the editor application settings.\n\n"
+                               "This is probably because the settings were changed between the Cppcheck versions. "
+                               "Please check (and fix) the editor application settings, otherwise the editor "
+                               "program might not start correctly.");
         QMessageBox msgBox(QMessageBox::Warning,
                            tr("Cppcheck"),
                            msg,
@@ -267,7 +298,7 @@ void MainWindow::DoCheckFiles(const QStringList &files)
     FileList pathList;
     pathList.AddPathList(files);
     if (mProject)
-        pathList.AddIngoreList(mProject->GetProjectFile()->GetIgnoredPaths());
+        pathList.AddExcludeList(mProject->GetProjectFile()->GetExcludedPaths());
     QStringList fileNames = pathList.GetFileList();
 
     mUI.mResults->Clear();
@@ -446,13 +477,6 @@ Settings MainWindow::GetCppcheckSettings()
 {
     Settings result;
 
-    QString globalIncludes = mSettings->value(SETTINGS_GLOBAL_INCLUDE_PATHS).toString();
-    if (!globalIncludes.isEmpty())
-    {
-        QStringList includes = globalIncludes.split(";");
-        AddIncludeDirs(includes, result);
-    }
-
     // If project file loaded, read settings from it
     if (mProject)
     {
@@ -470,7 +494,19 @@ Settings MainWindow::GetCppcheckSettings()
         }
     }
 
+    // Include directories (and files) are searched in listed order.
+    // Global include directories must be added AFTER the per project include
+    // directories so per project include directories can override global ones.
+    const QString globalIncludes = mSettings->value(SETTINGS_GLOBAL_INCLUDE_PATHS).toString();
+    if (!globalIncludes.isEmpty())
+    {
+        QStringList includes = globalIncludes.split(";");
+        AddIncludeDirs(includes, result);
+    }
+
     result.addEnabled("style");
+    result.addEnabled("performance");
+    result.addEnabled("portability");
     result.addEnabled("information");
     result.addEnabled("missingInclude");
     result.debug = false;
@@ -482,6 +518,7 @@ Settings MainWindow::GetCppcheckSettings()
     result._jobs = mSettings->value(SETTINGS_CHECK_THREADS, 1).toInt();
     result._inlineSuppressions = mSettings->value(SETTINGS_INLINE_SUPPRESSIONS, false).toBool();
     result.inconclusive = mSettings->value(SETTINGS_INCONCLUSIVE_ERRORS, false).toBool();
+    result.platformType = (Settings::PlatformType) mSettings->value(SETTINGS_CHECKED_PLATFORM, 0).toInt();
 
     if (result._jobs <= 0)
     {
@@ -565,7 +602,7 @@ void MainWindow::ClearResults()
 void MainWindow::OpenXML()
 {
     QString selectedFilter;
-    QString filter(tr("XML files (*.xml)"));
+    const QString filter(tr("XML files (*.xml)"));
     QString selectedFile = QFileDialog::getOpenFileName(this,
                            tr("Open the report file"),
                            QString(),
@@ -639,8 +676,8 @@ void MainWindow::closeEvent(QCloseEvent *event)
     }
     else
     {
-        QString text(tr("Checking is running.\n\n" \
-                        "Do you want to stop the checking and exit Cppcheck?."));
+        const QString text(tr("Checking is running.\n\n" \
+                              "Do you want to stop the checking and exit Cppcheck?."));
 
         QMessageBox msg(QMessageBox::Warning,
                         tr("Cppcheck"),
@@ -701,7 +738,7 @@ void MainWindow::ShowAuthors()
 void MainWindow::Save()
 {
     QString selectedFilter;
-    QString filter(tr("XML files version 2 (*.xml);;XML files version 1 (*.xml);;Text files (*.txt);;CSV files (*.csv)"));
+    const QString filter(tr("XML files version 2 (*.xml);;XML files version 1 (*.xml);;Text files (*.txt);;CSV files (*.csv)"));
     QString selectedFile = QFileDialog::getSaveFileName(this,
                            tr("Save the report file"),
                            QString(),
@@ -856,8 +893,16 @@ void MainWindow::LoadProjectFile(const QString &filePath)
     mUI.mActionEditProjectFile->setEnabled(true);
     delete mProject;
     mProject = new Project(filePath, this);
-    mProject->Open();
-    QString rootpath = mProject->GetProjectFile()->GetRootPath();
+    CheckProject(mProject);
+}
+
+void MainWindow::CheckProject(Project *project)
+{
+    if (!project->IsOpen())
+        project->Open();
+
+    QFileInfo inf(project->Filename());
+    const QString rootpath = project->GetProjectFile()->GetRootPath();
 
     // If the root path is not given or is not "current dir", use project
     // file's location directory as root path
@@ -866,7 +911,7 @@ void MainWindow::LoadProjectFile(const QString &filePath)
     else
         mCurrentDirectory = rootpath;
 
-    QStringList paths = mProject->GetProjectFile()->GetCheckPaths();
+    QStringList paths = project->GetProjectFile()->GetCheckPaths();
 
     // If paths not given then check the root path (which may be the project
     // file's location, see above). This is to keep the compatibility with
@@ -911,6 +956,7 @@ void MainWindow::NewProjectFile()
         mProject->Edit();
     }
     AddProjectMRU(filepath);
+    CheckProject(mProject);
 }
 
 void MainWindow::CloseProjectFile()
@@ -1010,9 +1056,9 @@ void MainWindow::OpenRecentProject()
         }
         else
         {
-            QString text(tr("The project file\n\n%1\n\n could not be found!\n\n"
-                            "Do you want to remove the file from the recently "
-                            "used projects -list?").arg(project));
+            const QString text(tr("The project file\n\n%1\n\n could not be found!\n\n"
+                                  "Do you want to remove the file from the recently "
+                                  "used projects -list?").arg(project));
 
             QMessageBox msg(QMessageBox::Warning,
                             tr("Cppcheck"),
@@ -1033,7 +1079,7 @@ void MainWindow::OpenRecentProject()
 
 void MainWindow::UpdateMRUMenuItems()
 {
-    for (int i = 0; i < MaxRecentProjects; i++)
+    for (int i = 0; i < MaxRecentProjects + 1; i++)
     {
         if (mRecentProjectActs[i] != NULL)
             mUI.mMenuFile->removeAction(mRecentProjectActs[i]);
@@ -1052,7 +1098,7 @@ void MainWindow::UpdateMRUMenuItems()
     }
 
     if (numRecentProjects > 1)
-        mUI.mMenuFile->insertSeparator(mUI.mActionProjectMRU);
+        mRecentProjectActs[numRecentProjects] = mUI.mMenuFile->insertSeparator(mUI.mActionProjectMRU);
 }
 
 void MainWindow::AddProjectMRU(const QString &project)
@@ -1075,3 +1121,13 @@ void MainWindow::RemoveProjectMRU(const QString &project)
     mSettings->setValue(SETTINGS_MRU_PROJECTS, files);
     UpdateMRUMenuItems();
 }
+
+void MainWindow::SelectPlatform()
+{
+    QAction *action = qobject_cast<QAction *>(sender());
+    if (action)
+    {
+        const Settings::PlatformType platform = (Settings::PlatformType) action->data().toInt();
+        mSettings->setValue(SETTINGS_CHECKED_PLATFORM, platform);
+    }
+}
