@@ -32,6 +32,7 @@
 #include "settingsdialog.h"
 #include "translationhandler.h"
 #include "settings.h"
+#include "platforms.h"
 #include "ui_main.h"
 
 class ThreadHandler;
@@ -61,6 +62,11 @@ public:
     MainWindow();
     virtual ~MainWindow();
 
+    /**
+      * List of checked platforms.
+      */
+    Platforms mPlatforms;
+
 public slots:
 
     /**
@@ -169,6 +175,12 @@ public slots:
     */
     void Save();
 
+    /**
+      * @brief Check the project.
+      * @param project Pointer to the project to check.
+      */
+    void CheckProject(Project *project);
+
     /**
     * @brief Slot to create new project file..
     *
@@ -279,6 +291,11 @@ protected slots:
     */
     void OpenRecentProject();
 
+    /**
+    * @brief Selects the platform as checked platform.
+    */
+    void SelectPlatform();
+
 protected:
 
     /**
@@ -467,9 +484,10 @@ private:
     bool mExiting;
 
     /**
-    * @brief Project MRU menu actions.
-    */
-    QAction *mRecentProjectActs[MaxRecentProjects];
+     * @brief Project MRU menu actions.
+     * List of MRU menu actions. Needs also to store the separator.
+     */
+    QAction *mRecentProjectActs[MaxRecentProjects + 1];
 };
 /// @}
 #endif // MAINWINDOW_H
