@@ -47,11 +47,21 @@ Project::~Project()
     delete mPFile;
 }
 
+QString Project::Filename() const
+{
+    return mFilename;
+}
+
 void Project::SetFilename(const QString &filename)
 {
     mFilename = filename;
 }
 
+bool Project::IsOpen() const
+{
+    return mPFile != NULL;
+}
+
 bool Project::Open()
 {
     mPFile = new ProjectFile(mFilename, this);
@@ -85,8 +95,8 @@ void Project::Edit()
     dlg.SetDefines(defines);
     QStringList paths = mPFile->GetCheckPaths();
     dlg.SetPaths(paths);
-    QStringList ignorepaths = mPFile->GetIgnoredPaths();
-    dlg.SetIgnorePaths(ignorepaths);
+    QStringList ignorepaths = mPFile->GetExcludedPaths();
+    dlg.SetExcludedPaths(ignorepaths);
 
     int rv = dlg.exec();
     if (rv == QDialog::Accepted)
@@ -99,8 +109,8 @@ void Project::Edit()
         mPFile->SetDefines(defines);
         QStringList paths = dlg.GetPaths();
         mPFile->SetCheckPaths(paths);
-        QStringList ignorepaths = dlg.GetIgnorePaths();
-        mPFile->SetIgnoredPaths(ignorepaths);
+        QStringList excludedpaths = dlg.GetExcludedPaths();
+        mPFile->SetExcludedPaths(excludedpaths);
 
         bool writeSuccess = mPFile->Write();
         if (!writeSuccess)
