@@ -1,6 +1,6 @@
 /*
  * Cppcheck - A tool for static C/C++ code analysis
- * Copyright (C) 2007-2010 Daniel Marjamäki and Cppcheck team.
+ * Copyright (C) 2007-2011 Daniel Marjamäki and Cppcheck team.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -16,7 +16,10 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include <QObject>
+#include <QString>
 #include <QFile>
+#include "erroritem.h"
 #include "report.h"
 
 Report::Report(const QString &filename, QObject * parent) :
@@ -41,6 +44,17 @@ bool Report::Create()
     return succeed;
 }
 
+bool Report::Open()
+{
+    bool succeed = false;
+    if (!mFile.isOpen())
+    {
+        mFile.setFileName(mFilename);
+        succeed = mFile.open(QIODevice::ReadOnly | QIODevice::Text);
+    }
+    return succeed;
+}
+
 void Report::Close()
 {
     if (mFile.isOpen())
