@@ -28,6 +28,7 @@
 #include <QTextStream>
 #include "common.h"
 #include "applicationlist.h"
+#include "errorlogger.h" // Severity
 
 class Report;
 class ErrorItem;
@@ -74,6 +75,14 @@ public:
     */
     void ShowResults(ShowTypes type, bool show);
 
+    /**
+    * @brief Function to filter the displayed list of errors.
+    * Refreshes the tree.
+    *
+    * @param filter String that must be found in the summary, description, file or id
+    */
+    void FilterResults(const QString& filter);
+
     /**
     * @brief Function to show results that were previous hidden with HideResult()
     */
@@ -128,10 +137,10 @@ public:
 
     /**
     * @brief Convert severity string to ShowTypes value
-    * @param severity Error severity string
+    * @param severity Error severity
     * @return Severity converted to ShowTypes value
     */
-    static ShowTypes SeverityToShowType(const QString &severity);
+    static ShowTypes SeverityToShowType(Severity::SeverityType severity);
 
 signals:
     /**
@@ -230,17 +239,18 @@ protected:
     /**
     * @brief Convert a severity string to a icon filename
     *
-    * @param severity Severity string
+    * @param severity Severity
     */
-    QString SeverityToIcon(const QString &severity) const;
+    QString SeverityToIcon(Severity::SeverityType severity) const;
 
     /**
     * @brief Helper function to open an error within target with application*
     *
     * @param target Error tree item to open
-    * @param application Index of the application to open with
+    * @param application Index of the application to open with. Giving -1
+    *  (default value) will open the default application.
     */
-    void StartApplication(QStandardItem *target, int application);
+    void StartApplication(QStandardItem *target, int application = -1);
 
     /**
     * @brief Helper function to copy filename/full path to the clipboard
@@ -290,9 +300,16 @@ protected:
     /**
     * @brief Convert ShowType to severity string
     * @param type ShowType to convert
-    * @return ShowType converted to string
+    * @return ShowType converted to severity
     */
-    QString ShowTypeToString(ShowTypes type);
+    Severity::SeverityType ShowTypeToSeverity(ShowTypes type);
+
+    /**
+    * @brief Convert Severity to translated string for GUI.
+    * @param type Severity to convert
+    * @return Severity as translated string
+    */
+    QString SeverityToTranslatedString(Severity::SeverityType severity);
 
     /**
     * @brief Load all settings
@@ -369,6 +386,12 @@ protected:
     */
     bool mShowTypes[SHOW_NONE];
 
+    /**
+    * @brief A string used to filter the results for display.
+    *
+    */
+    QString mFilter;
+
     /**
     * @brief List of applications to open errors with
     *
