@@ -22,7 +22,7 @@
 
 
 #include <QWidget>
-#include "../lib/errorlogger.h"
+#include "errorlogger.h"
 #include "common.h"
 #include "report.h"
 #include "ui_resultsview.h"
@@ -173,8 +173,9 @@ public slots:
     * @brief Slot for updating the checking progress
     *
     * @param value Current progress value
+    * @param description Description to accompany the progress
     */
-    void Progress(int value);
+    void Progress(int value, const QString& description);
 
     /**
     * @brief Slot for new error to be displayed
@@ -225,7 +226,6 @@ protected:
 
     CheckStatistics *mStatistics;
 
-
 private:
 };
 /// @}
