@@ -110,9 +110,6 @@ public:
     /** Check for negative index */
     void negativeIndex();
 
-    /** Check for buffer overruns */
-    void checkScope(const Token *tok, const std::vector<std::string> &varname, const MathLib::bigint size, const MathLib::bigint total_size, unsigned int varid);
-
     /** Information about N-dimensional array */
     class ArrayInfo
     {
@@ -165,6 +162,10 @@ public:
         {
             return _num[index];
         }
+        void num(size_t index, MathLib::bigint number)
+        {
+            _num[index] = number;
+        }
 
         /** size of each element */
         MathLib::bigint element_size() const
@@ -177,17 +178,28 @@ public:
         {
             return _varid;
         }
+        void varid(unsigned int id)
+        {
+            _varid = id;
+        }
 
         /** Variable name */
         const std::string &varname() const
         {
             return _varname;
         }
+        void varname(const std::string &name)
+        {
+            _varname = name;
+        }
     };
 
     /** Check for buffer overruns (based on ArrayInfo) */
     void checkScope(const Token *tok, const ArrayInfo &arrayInfo);
 
+    /** Check for buffer overruns */
+    void checkScope(const Token *tok, const std::vector<std::string> &varname, const ArrayInfo &arrayInfo);
+
     /** Check scope helper function - parse for body */
     void checkScopeForBody(const Token *tok, const ArrayInfo &arrayInfo, bool &bailout);
 
@@ -209,32 +221,37 @@ public:
      */
     void checkFunctionCall(const Token *tok, const ArrayInfo &arrayInfo);
 
-    void arrayIndexOutOfBounds(const Token *tok, MathLib::bigint size, MathLib::bigint index);
-    void arrayIndexOutOfBounds(const Token *tok, const ArrayInfo &arrayInfo, const std::vector<MathLib::bigint> &index);
-    void arrayIndexOutOfBounds(const std::list<const Token *> &callstack, const ArrayInfo &arrayInfo, const std::vector<MathLib::bigint> &index);
-    void bufferOverrun(const Token *tok, const std::string &varnames = "");
-    void strncatUsage(const Token *tok);
-    void outOfBounds(const Token *tok, const std::string &what);
-    void sizeArgumentAsChar(const Token *tok);
-    void terminateStrncpyError(const Token *tok);
+    void arrayIndexOutOfBoundsError(const Token *tok, const ArrayInfo &arrayInfo, const std::vector<MathLib::bigint> &index);
+    void arrayIndexOutOfBoundsError(const std::list<const Token *> &callstack, const ArrayInfo &arrayInfo, const std::vector<MathLib::bigint> &index);
+    void bufferOverrunError(const Token *tok, const std::string &varnames = "");
+    void strncatUsageError(const Token *tok);
+    void outOfBoundsError(const Token *tok, const std::string &what, const bool show_size_info, const MathLib::bigint &supplied_size, const MathLib::bigint &actual_size);
+    void sizeArgumentAsCharError(const Token *tok);
+    void terminateStrncpyError(const Token *tok, const std::string &varname);
+    void bufferNotZeroTerminatedError(const Token *tok, const std::string &varname, const std::string &function);
     void negativeIndexError(const Token *tok, MathLib::bigint index);
     void cmdLineArgsError(const Token *tok);
-    void pointerOutOfBounds(const Token *tok, const std::string &object);	// UB when result of calculation is out of bounds
+    void pointerOutOfBoundsError(const Token *tok, const std::string &object);	// UB when result of calculation is out of bounds
     void arrayIndexThenCheckError(const Token *tok, const std::string &indexName);
+    void possibleBufferOverrunError(const Token *tok, const std::string &src, const std::string &dst, bool cat);
 
     void getErrorMessages(ErrorLogger *errorLogger, const Settings *settings)
     {
         CheckBufferOverrun c(0, settings, errorLogger);
-        c.arrayIndexOutOfBounds(0, 2, 2);
-        c.bufferOverrun(0, std::string("buffer"));
-        c.strncatUsage(0);
-        c.outOfBounds(0, "index");
-        c.sizeArgumentAsChar(0);
-        c.terminateStrncpyError(0);
+        std::vector<MathLib::bigint> indexes;
+        indexes.push_back(2);
+        c.arrayIndexOutOfBoundsError(0, ArrayInfo(0, "array", 1, 2), indexes);
+        c.bufferOverrunError(0, std::string("buffer"));
+        c.strncatUsageError(0);
+        c.outOfBoundsError(0, "index", true, 2, 1);
+        c.sizeArgumentAsCharError(0);
+        c.terminateStrncpyError(0, "buffer");
+        c.bufferNotZeroTerminatedError(0, "buffer", "strncpy");
         c.negativeIndexError(0, -1);
         c.cmdLineArgsError(0);
-        c.pointerOutOfBounds(0, "array");
+        c.pointerOutOfBoundsError(0, "array");
         c.arrayIndexThenCheckError(0, "index");
+        c.possibleBufferOverrunError(0, "source", "destination", false);
     }
 
     std::string myName() const
