@@ -340,6 +340,10 @@ void CheckClass::initializeVarList(const Function &func, std::list<std::string>
         // Goto the first token in this statement..
         ftok = ftok->next();
 
+        // skip "return"
+        if (ftok->str() == "return")
+            ftok = ftok->next();
+
         // Skip "( * this )"
         if (Token::simpleMatch(ftok, "( * this ) ."))
         {
@@ -374,6 +378,16 @@ void CheckClass::initializeVarList(const Function &func, std::list<std::string>
         else if (Token::simpleMatch(ftok, "operator= (") &&
                  ftok->previous()->str() != "::")
         {
+            // recursive call / calling overloaded function
+            // assume that all variables are initialized
+            if (std::find(callstack.begin(), callstack.end(), ftok->str()) != callstack.end())
+            {
+                /** @todo false negative: just bail */
+                assignAllVar(usage);
+                return;
+            }
+
+            /** @todo check function parameters for overloaded function so we check the right one */
             // check if member function exists
             std::list<Function>::const_iterator it;
             for (it = scope->functionList.begin(); it != scope->functionList.end(); ++it)
@@ -823,7 +837,17 @@ void CheckClass::operatorEq()
                 // use definition for check so we don't have to deal with qualification
                 if (!(Token::Match(func->tokenDef->tokAt(-3), ";|}|{|public:|protected:|private: %type% &") &&
                       func->tokenDef->strAt(-2) == scope->className))
-                    operatorEqReturnError(func->tokenDef->tokAt(-1), scope->className);
+                {
+                    // make sure we really have a copy assignment operator
+                    if (Token::Match(func->tokenDef->tokAt(2), "const| %var% &"))
+                    {
+                        if (func->tokenDef->strAt(2) == "const" &&
+                            func->tokenDef->strAt(3) == scope->className)
+                            operatorEqReturnError(func->tokenDef->tokAt(-1), scope->className);
+                        else if (func->tokenDef->strAt(2) == scope->className)
+                            operatorEqReturnError(func->tokenDef->tokAt(-1), scope->className);
+                    }
+                }
             }
         }
     }
@@ -1409,6 +1433,10 @@ bool CheckClass::isMemberVar(const Scope *scope, const Token *tok)
         {
             return true;
         }
+        else if (Token::Match(tok->tokAt(-3), "( * this )"))
+        {
+            return true;
+        }
         else if (Token::Match(tok->tokAt(-2), "%var% . %var%"))
         {
             tok = tok->tokAt(-2);
@@ -1493,15 +1521,25 @@ bool CheckClass::isConstMemberFunc(const Scope *scope, const Token *tok)
     unsigned int args = countParameters(tok);
 
     std::list<Function>::const_iterator    func;
+    unsigned int matches = 0;
+    unsigned int consts = 0;
 
     for (func = scope->functionList.begin(); func != scope->functionList.end(); ++func)
     {
         /** @todo we need to look at the argument types when there are overloaded functions
           * with the same number of arguments */
-        if (func->tokenDef->str() == tok->str() && func->argCount() == args && func->isConst)
-            return true;
+        if (func->tokenDef->str() == tok->str() && func->argCount() == args)
+        {
+            matches++;
+            if (func->isConst)
+                consts++;
+        }
     }
 
+    // if there are multiple matches that are all const, return const
+    if (matches > 0 && matches == consts)
+        return true;
+
     // not found in this class
     if (!scope->derivedFrom.empty())
     {
@@ -1568,6 +1606,13 @@ bool CheckClass::checkConstFunc(const Scope *scope, const Token *tok)
             break;
         }
 
+        // streaming: >>
+        else if (tok1->str() == ">>" && isMemberVar(scope, tok1->next()))
+        {
+            isconst = false;
+            break;
+        }
+
         // increment/decrement (member variable?)..
         else if (Token::Match(tok1, "++|--"))
         {
@@ -1618,7 +1663,7 @@ bool CheckClass::checkConstFunc(const Scope *scope, const Token *tok)
 
         // function call..
         else if (Token::Match(tok1, "%var% (") &&
-                 !(Token::Match(tok1, "return|c_str|if|string") || tok1->isStandardType()))
+                 !(Token::Match(tok1, "return|c_str|if|string|switch|while|catch|for") || tok1->isStandardType()))
         {
             if (!isConstMemberFunc(scope, tok1))
             {
@@ -1717,7 +1762,7 @@ bool CheckClass::isVirtualFunc(const Scope *scope, const Token *functionToken) c
 
 void CheckClass::checkConstError(const Token *tok, const std::string &classname, const std::string &funcname)
 {
-    reportError(tok, Severity::information, "functionConst",
+    reportError(tok, Severity::style, "functionConst",
                 "Technically the member function '" + classname + "::" + funcname + "' can be const.\n"
                 "The member function '" + classname + "::" + funcname + "' can be made a const "
                 "function. Making this function const function should not cause compiler errors. "
@@ -1731,7 +1776,7 @@ void CheckClass::checkConstError2(const Token *tok1, const Token *tok2, const st
     std::list<const Token *> toks;
     toks.push_back(tok1);
     toks.push_back(tok2);
-    reportError(toks, Severity::information, "functionConst",
+    reportError(toks, Severity::style, "functionConst",
                 "Technically the member function '" + classname + "::" + funcname + "' can be const.\n"
                 "The member function '" + classname + "::" + funcname + "' can be made a const "
                 "function. Making this function const function should not cause compiler errors. "
@@ -1739,3 +1784,104 @@ void CheckClass::checkConstError2(const Token *tok1, const Token *tok2, const st
                 "sense conceptually. Think about your design and task of the function first - is "
                 "it a function that must not change object internal state?");
 }
+
+//---------------------------------------------------------------------------
+// ClassCheck: Check that initializer list is in declared order.
+//---------------------------------------------------------------------------
+
+struct VarInfo
+{
+    VarInfo(const Variable *_var, const Token *_tok)
+        : var(_var), tok(_tok) { }
+
+    const Variable *var;
+    const Token *tok;
+};
+
+void CheckClass::initializerList()
+{
+    if (!_settings->isEnabled("style"))
+        return;
+
+    // This check is not inconclusive.  However it only determines if the initialization
+    // order is incorrect.  It does not determine if being out of order causes
+    // a real error.  Out of order is not necessarily an error but you can never
+    // have an error if the list is in order so this enforces defensive programming.
+    if (!_settings->inconclusive)
+        return;
+
+    createSymbolDatabase();
+
+    std::list<Scope>::const_iterator info;
+
+    // iterate through all scopes looking for classes and structures
+    for (info = symbolDatabase->scopeList.begin(); info != symbolDatabase->scopeList.end(); ++info)
+    {
+        if (!info->isClassOrStruct())
+            continue;
+
+        std::list<Function>::const_iterator func;
+
+        // iterate through all member functions looking for constructors
+        for (func = info->functionList.begin(); func != info->functionList.end(); ++func)
+        {
+            if (func->type == Function::eConstructor && func->hasBody)
+            {
+                // check for initializer list
+                const Token *tok = func->arg->link()->next();
+
+                if (tok->str() == ":")
+                {
+                    std::vector<VarInfo> vars;
+                    tok = tok->next();
+
+                    // find all variable initializations in list
+                    while (tok && tok->str() != "{")
+                    {
+                        if (Token::Match(tok, "%var% ("))
+                        {
+                            const Variable *var = info->getVariable(tok->str());
+
+                            if (var)
+                                vars.push_back(VarInfo(var, tok));
+
+                            if (Token::Match(tok->tokAt(2), "%var% ="))
+                            {
+                                var = info->getVariable(tok->strAt(2));
+
+                                if (var)
+                                    vars.push_back(VarInfo(var, tok->tokAt(2)));
+                            }
+                        }
+                        tok = tok->next();
+                    }
+
+                    // need at least 2 members to have out of order initialization
+                    if (vars.size() > 1)
+                    {
+                        for (unsigned int i = 1; i < vars.size(); i++)
+                        {
+                            // check for out of order initialization
+                            if (vars[i].var->index() < vars[i - 1].var->index())
+                                initializerListError(vars[i].tok,vars[i].var->nameToken(), info->className, vars[i].var->name());
+                        }
+                    }
+                }
+            }
+        }
+    }
+}
+
+void CheckClass::initializerListError(const Token *tok1, const Token *tok2, const std::string &classname, const std::string &varname)
+{
+    std::list<const Token *> toks;
+    toks.push_back(tok1);
+    toks.push_back(tok2);
+    reportError(toks, Severity::style, "initializerList",
+                "Member variable '" + classname + "::" +
+                varname + "' is in the wrong order in the initializer list.\n"
+                "Members are initialized in the order they are declared, not the "
+                "order they are in the initializer list.  Keeping the initializer list "
+                "in the same order that the members were declared prevents order dependent "
+                "initialization errors.");
+}
