@@ -28,7 +28,7 @@
  *
  * %Check for memory leaks
  *
- * The checking is split up into two specialized classes.
+ * The checking is split up into three specialized classes.
  * - CheckMemoryLeakInFunction can detect when a function variable is allocated but not deallocated properly.
  * - CheckMemoryLeakInClass can detect when a class variable is allocated but not deallocated properly.
  * - CheckMemoryLeakStructMember checks allocation/deallocation of structs and struct members
@@ -124,12 +124,24 @@ public:
     /**
      * @brief Is a typename the name of a class?
      * @param _tokenizer tokenizer
-     * @param typestr type name
+     * @param tok type token
+     * @param varid variable id
      * @return true if the type name is the name of a class
      */
-    bool isclass(const Tokenizer *_tokenizer, const Token *typestr, unsigned int varid) const;
+    bool isclass(const Tokenizer *_tokenizer, const Token *tok, unsigned int varid) const;
 
+    /**
+     * Report that there is a memory leak (new/malloc/etc)
+     * @param tok token where memory is leaked
+     * @param varname name of variable
+     */
     void memleakError(const Token *tok, const std::string &varname);
+
+    /**
+     * Report that there is a resource leak (fopen/popen/etc)
+     * @param tok token where resource is leaked
+     * @param varname name of variable
+     */
     void resourceLeakError(const Token *tok, const std::string &varname);
 
     /**
@@ -264,23 +276,23 @@ public:
      * @return Newly allocated token array. Caller needs to release reserved
      * memory by calling Tokenizer::deleteTokens(returnValue);
      * Returned tokens:
-     * - alloc : the variable is allocated
-     * - assign : the variable is assigned a new value
-     * - break : corresponds to "break"
-     * - callfunc : a function call with unknown side effects
-     * - continue : corresponds to "continue"
-     * - dealloc : the variable is deallocated
-     * - goto : corresponds to a "goto"
-     * - if : there is an "if"
-     * - if(var) : corresponds with "if ( var != 0 )"
-     * - if(!var) : corresponds with "if ( var == 0 )"
-     * - ifv : the variable is used in some way in a "if"
-     * - loop : corresponds to either a "for" or a "while"
-     * - realloc : the variable is reallocated
-     * - return : corresponds to a "return"
-     * - use : unknown usage -> bail out checking of this execution path
-     * - &use : the address of the variable is taken
-     * - ::use : calling member function of class
+     * - "alloc" : the variable is allocated
+     * - "assign" : the variable is assigned a new value
+     * - "break" : corresponds to "break"
+     * - "callfunc" : a function call with unknown side effects
+     * - "continue" : corresponds to "continue"
+     * - "dealloc" : the variable is deallocated
+     * - "goto" : corresponds to a "goto"
+     * - "if" : there is an "if"
+     * - "if(var)" : corresponds with "if ( var != 0 )"
+     * - "if(!var)" : corresponds with "if ( var == 0 )"
+     * - "ifv" : the variable is used in some way in a "if"
+     * - "loop" : corresponds to either a "for" or a "while"
+     * - "realloc" : the variable is reallocated
+     * - "return" : corresponds to a "return"
+     * - "use" : unknown usage -> bail out checking of this execution path
+     * - "&use" : the address of the variable is taken
+     * - "::use" : calling member function of class
      */
     Token *getcode(const Token *tok, std::list<const Token *> callstack, const unsigned int varid, AllocType &alloctype, AllocType &dealloctype, bool classmember, unsigned int sz);
 
