@@ -118,6 +118,15 @@ void CheckNullPointer::parseFunctionCall(const Token &tok, std::list<const Token
         if (functionNames2.find(tok.str()) != functionNames2.end())
             var.push_back(tok.tokAt(4));
     }
+
+    // TODO: Handle sprintf/printf better.
+    if (Token::Match(&tok, "printf ( %str% , %var% ,|)") && tok.tokAt(4)->varId() > 0)
+    {
+        const std::string &formatstr(tok.tokAt(2)->str());
+        const std::string::size_type pos = formatstr.find("%");
+        if (pos != std::string::npos && formatstr.compare(pos,2,"%s") == 0)
+            var.push_back(tok.tokAt(4));
+    }
 }
 
 
@@ -358,6 +367,18 @@ void CheckNullPointer::nullPointerStructByDeRefAndChec()
             skipvar.insert(tok1->varId());
             continue;
         }
+        else if (Token::Match(tok1, "( ! %var% ||") ||
+                 Token::Match(tok1, "( %var% &&"))
+        {
+            // TODO: there are false negatives caused by this. The
+            // variable should be removed from skipvar after the
+            // condition
+            tok1 = tok1->next();
+            if (tok1->str() == "!")
+                tok1 = tok1->next();
+            skipvar.insert(tok1->varId());
+            continue;
+        }
 
         /**
          * @todo There are lots of false negatives here. A dereference
@@ -505,6 +526,8 @@ void CheckNullPointer::nullPointerStructByDeRefAndChec()
 
 void CheckNullPointer::nullPointerByDeRefAndChec()
 {
+    const SymbolDatabase *symbolDatabase = _tokenizer->getSymbolDatabase();
+
     // Dereferencing a pointer and then checking if it's NULL..
     // This check will first scan for the check. And then scan backwards
     // from the check, searching for dereferencing.
@@ -532,7 +555,11 @@ void CheckNullPointer::nullPointerByDeRefAndChec()
                 continue;
 
             // Token where pointer is declared
-            const Token * const decltok = Token::findmatch(_tokenizer->tokens(), "%varid%", varid);
+            const Variable *var = symbolDatabase->getVariableFromVarId(varid);
+            if (!var)
+                continue;
+
+            const Token * const decltok = var->nameToken();
 
             for (const Token *tok1 = tok->previous(); tok1 && tok1 != decltok; tok1 = tok1->previous())
             {
@@ -549,6 +576,13 @@ void CheckNullPointer::nullPointerByDeRefAndChec()
                     if (Token::Match(tok1->link()->previous(), "while ( %varid%", varid))
                         break;
 
+                    // TODO: there might be false negatives. perhaps
+                    // instead of bailing out it's ok to skip the condition.
+                    // this bailout is related to #3128
+                    if (Token::Match(tok1->link(), "( ! %varid% ||", varid) ||
+                        Token::Match(tok1->link(), "( %varid% &&", varid))
+                        break;
+
                     if (Token::simpleMatch(tok1->link()->previous(), "sizeof ("))
                     {
                         tok1 = tok1->link()->previous();
@@ -557,9 +591,9 @@ void CheckNullPointer::nullPointerByDeRefAndChec()
 
                     if (Token::Match(tok2, "[;{}] %var% ( %varid% ,", varid))
                     {
-                        std::list<const Token *> var;
-                        parseFunctionCall(*(tok2->next()), var, 0);
-                        if (!var.empty() && var.front() == tok2->tokAt(3))
+                        std::list<const Token *> varlist;
+                        parseFunctionCall(*(tok2->next()), varlist, 0);
+                        if (!varlist.empty() && varlist.front() == tok2->tokAt(3))
                         {
                             nullPointerError(tok2->tokAt(3), varname, tok->linenr());
                             break;
@@ -567,16 +601,30 @@ void CheckNullPointer::nullPointerByDeRefAndChec()
                     }
 
                     // calling unknown function => it might initialize the pointer
-                    const Variable *var = _tokenizer->getSymbolDatabase()->getVariableFromVarId(varid);
-                    if (!var || !(var->isLocal() || var->isArgument()))
+                    if (!(var->isLocal() || var->isArgument()))
                         break;
                 }
 
                 if (tok1->str() == "break")
                     break;
 
-                if (tok1->varId() == varid && !Token::Match(tok1->previous(), "[?:]"))
+                if (tok1->varId() == varid)
                 {
+                    // Don't write warning if the dereferencing is
+                    // guarded by ?:
+                    const Token *tok2 = tok1->previous();
+                    if (tok2 && (tok2->isArithmeticalOp() || tok2->str() == "("))
+                    {
+                        while (tok2 && !Token::Match(tok2, "[;{}?:]"))
+                        {
+                            if (tok2->str() == ")")
+                                tok2 = tok2->link();
+                            tok2 = tok2->previous();
+                        }
+                    }
+                    if (Token::Match(tok2, "[?:]"))
+                        continue;
+
                     // unknown : this is set by isPointerDeRef if it is
                     //           uncertain
                     bool unknown = false;
@@ -585,6 +633,14 @@ void CheckNullPointer::nullPointerByDeRefAndChec()
                     {
                         break;
                     }
+                    else if (Token::Match(tok1->previous(), "&&|%oror%"))
+                    {
+                        break;
+                    }
+                    else if (Token::Match(tok1->tokAt(-2), "&&|%oror% !"))
+                    {
+                        break;
+                    }
                     else if (CheckNullPointer::isPointerDeRef(tok1, unknown))
                     {
                         nullPointerError(tok1, varname, tok->linenr());
@@ -750,7 +806,7 @@ void CheckNullPointer::nullPointerByCheckAndDeRef()
 
                 // calling unknown function (abort/init)..
                 if (Token::simpleMatch(tok2, ") ;") &&
-                    (Token::Match(tok2->link()->tokAt(-2), "[;{}] %var% (") ||
+                    (Token::Match(tok2->link()->tokAt(-2), "[;{}.] %var% (") ||
                      Token::Match(tok2->link()->tokAt(-5), "[;{}] ( * %var% ) (")))
                 {
                     // noreturn function?
@@ -844,7 +900,7 @@ void CheckNullPointer::nullConstantDereference()
                 }
             }
 
-            else if (indentlevel > 0 && Token::Match(tok, "%var% ("))
+            else if (indentlevel > 0 && Token::Match(tok->previous(), "[={};] %var% ("))
             {
                 std::list<const Token *> var;
                 parseFunctionCall(*tok, var, 0);
