@@ -21,6 +21,7 @@
 //---------------------------------------------------------------------------
 
 #include "checkobsoletefunctions.h"
+#include "symboldatabase.h"
 
 //---------------------------------------------------------------------------
 
@@ -40,31 +41,49 @@ void CheckObsoleteFunctions::obsoleteFunctions()
     if (_tokenizer->isJavaOrCSharp())
         return;
 
+    const SymbolDatabase *symbolDatabase = _tokenizer->getSymbolDatabase();
+
     for (const Token *tok = _tokenizer->tokens(); tok; tok = tok->next())
     {
         if (tok->isName() && tok->varId()==0 && tok->strAt(1) == "(" && !Token::Match(tok->previous(), ".|::|:|,"))
         {
             // function declaration?
-            if (tok->previous() && tok->previous()->isName())
+            if (symbolDatabase->findFunctionByToken(tok))
+            {
+                _obsoleteStandardFunctions.erase(tok->str());
+                _obsoletePosixFunctions.erase(tok->str());
                 continue;
+            }
 
             std::map<std::string,std::string>::const_iterator it = _obsoleteStandardFunctions.find(tok->str());
             if (it != _obsoleteStandardFunctions.end())
             {
                 // If checking an old code base it might be uninteresting to update obsolete functions.
                 // Therefore this is "information"
-                reportError(tok->tokAt(1), Severity::information, "obsoleteFunctions"+it->first, it->second);
+                reportError(tok->tokAt(1), Severity::style, "obsoleteFunctions"+it->first, it->second);
                 break;
             }
-            else if (_settings->posix)
+            else
             {
-                it = _obsoletePosixFunctions.find(tok->str());
-                if (it != _obsoletePosixFunctions.end())
+                if (_settings->posix)
                 {
-                    // If checking an old code base it might be uninteresting to update obsolete functions.
-                    // Therefore this is "information"
-                    reportError(tok->tokAt(1), Severity::information, "obsoleteFunctions"+it->first, it->second);
-                    break;
+                    it = _obsoletePosixFunctions.find(tok->str());
+                    if (it != _obsoletePosixFunctions.end())
+                    {
+                        // If checking an old code base it might be uninteresting to update obsolete functions.
+                        // Therefore this is "information"
+                        reportError(tok->tokAt(1), Severity::style, "obsoleteFunctions"+it->first, it->second);
+                        break;
+                    }
+                }
+                if (_settings->c99)
+                {
+                    it = _obsoleteC99Functions.find(tok->str());
+                    if (it != _obsoleteC99Functions.end())
+                    {
+                        reportError(tok->tokAt(1), Severity::style, "obsoleteFunctions"+it->first, it->second);
+                        break;
+                    }
                 }
             }
         }
