@@ -591,7 +591,7 @@ SymbolDatabase::SymbolDatabase(const Tokenizer *tokenizer, const Settings *setti
                 }
                 else if (tok->str() == "{")
                 {
-                    if (!Token::Match(tok->previous(), "=|,|{"))
+                    if (!Token::Match(tok->previous(), "=|,"))
                     {
                         scopeList.push_back(Scope(this, tok, scope, Scope::eUnconditional, tok));
                         scope = &scopeList.back();
@@ -813,7 +813,8 @@ SymbolDatabase::SymbolDatabase(const Tokenizer *tokenizer, const Settings *setti
             for (size_t j = 0; j < _variableList[i]->dimensions().size(); j++)
             {
                 // check for a single token dimension that is a variable
-                if ((_variableList[i]->dimensions()[j].start == _variableList[i]->dimensions()[j].end) &&
+                if (_variableList[i]->dimensions()[j].start &&
+                    (_variableList[i]->dimensions()[j].start == _variableList[i]->dimensions()[j].end) &&
                     _variableList[i]->dimensions()[j].start->varId())
                 {
                     Dimension &dimension = const_cast<Dimension &>(_variableList[i]->dimensions()[j]);
@@ -919,8 +920,13 @@ bool SymbolDatabase::argsMatch(const Scope *scope, const Token *first, const Tok
 
         // skip default value assignment
         else if (first->next()->str() == "=")
+        {
             first = first->tokAt(2);
 
+            if (second->next()->str() == "=")
+                second = second->tokAt(2);
+        }
+
         // definition missing variable name
         else if (first->next()->str() == "," && second->next()->str() != ",")
             second = second->next();
@@ -1256,10 +1262,10 @@ const Token *SymbolDatabase::initBaseInfo(Scope *scope, const Token *tok)
             }
 
             base.name += tok2->str();
-            base.scope = 0;
+            base.scope = NULL;
 
             // add unhandled templates
-            if (tok2->next()->str() == "<")
+            if (tok2->next() && tok2->next()->str() == "<")
             {
                 tok2 = tok2->next();
                 base.name += tok2->str();
@@ -1319,14 +1325,17 @@ bool SymbolDatabase::arrayDimensions(std::vector<Dimension> &dimensions, const T
 
     const Token *dim = tok;
 
-    while (dim && dim->next() && dim->str() == "[" && dim->next()->str() != "]")
+    while (dim && dim->next() && dim->str() == "[")
     {
         Dimension dimension;
-        dimension.num = 0;
-        dimension.start = dim->next();
-        dimension.end = dim->link()->previous();
-        if (dimension.start == dimension.end && dimension.start->isNumber())
-            dimension.num = MathLib::toLongNumber(dimension.start->str());
+        // check for empty array dimension []
+        if (dim->next()->str() != "]")
+        {
+            dimension.start = dim->next();
+            dimension.end = dim->link()->previous();
+            if (dimension.start == dimension.end && dimension.start->isNumber())
+                dimension.num = MathLib::toLongNumber(dimension.start->str());
+        }
         dimensions.push_back(dimension);
         dim = dim->link()->next();
         isArray = true;
@@ -1383,6 +1392,11 @@ void Function::addArguments(const SymbolDatabase *symbolDatabase, const Function
                 else if (tok->str() == "[")
                 {
                     isArrayVar = symbolDatabase->arrayDimensions(dimensions, tok);
+
+                    // skip array dimension(s)
+                    tok = tok->link();
+                    while (tok->next()->str() == "[")
+                        tok = tok->next()->link();
                 }
                 else if (tok->str() == "<")
                 {
@@ -1683,6 +1697,11 @@ void Scope::getVariableList()
             continue;
         else if (Token::Match(tok, ";|{|}"))
             continue;
+        else if (Token::Match(tok, "goto %var% ;"))
+        {
+            tok = tok->next()->next();
+            continue;
+        }
 
         tok = checkVariable(tok, varaccess);
 
@@ -1770,6 +1789,19 @@ const Token *Scope::checkVariable(const Token *tok, AccessControl varaccess)
     return tok;
 }
 
+const Variable *Scope::getVariable(const std::string &varname) const
+{
+    std::list<Variable>::const_iterator iter;
+
+    for (iter = varlist.begin(); iter != varlist.end(); ++iter)
+    {
+        if (iter->name() == varname)
+            return &*iter;
+    }
+
+    return NULL;
+}
+
 const Token* skipScopeIdentifiers(const Token* tok)
 {
     const Token* ret = tok;
@@ -1905,8 +1937,16 @@ const Scope *SymbolDatabase::findVariableType(const Scope *start, const Token *t
                 const Scope *parent = start;
 
                 // check if in same namespace
-                while (parent && parent != scope->nestedIn)
-                    parent = parent->nestedIn;
+                while (parent)
+                {
+                    // out of line class function belongs to class
+                    if (parent->type == Scope::eFunction && parent->functionOf)
+                        parent = parent->functionOf;
+                    else if (parent != scope->nestedIn)
+                        parent = parent->nestedIn;
+                    else
+                        break;
+                }
 
                 if (scope->nestedIn == parent)
                     return &(*scope);
