@@ -199,6 +199,12 @@ public:
     /** Remove redundant assignment */
     void removeRedundantAssignment();
 
+    /**
+     * Remove redudant code placed after 'return ;' code.
+     * @todo Extend the functionality to code after 'break;' and 'continue;' code
+     */
+    void simplifyDeadCode();
+
     /**
      * Replace sizeof() to appropriate size.
      */
@@ -218,6 +224,13 @@ public:
     void simplifyInitVar();
     Token * initVar(Token * tok);
 
+    /**
+     * Convert platform dependent types to standard types.
+     * 32 bits: size_t -> unsigned long
+     * 64 bits: size_t -> unsigned long long
+     */
+    void simplifyPlatformTypes();
+
     /**
      * Collapse compound standard types into a single token.
      * unsigned long long int => long _isUnsigned=true,_isLong=true
@@ -359,6 +372,13 @@ public:
      */
     bool removeReduntantConditions();
 
+    /**
+     * Remove redundant for:
+     * "for (x=0;x<1;x++) { }" => "{ x = 1; }"
+     */
+    void removeRedundantFor();
+
+
     /**
      * Reduces "; ;" to ";", except in "( ; ; )"
      */
@@ -602,8 +622,23 @@ public:
     void simplifyMicrosoftMFC();
 
     /**
-     * Remove Borland code
-     */
+    * Convert Microsoft memory functions
+    * CopyMemory(dst, src, len) -> memcpy(dst, src, len)
+    * FillMemory(dst, len, val) -> memset(dst, val, len)
+    * MoveMemory(dst, src, len) -> memmove(dst, src, len)
+    * ZeroMemory(dst, len) -> memset(dst, 0, len)
+    */
+    void simplifyMicrosoftMemoryFunctions();
+
+    /**
+    * Convert Microsoft string functions
+    * _tcscpy -> strcpy
+    */
+    void simplifyMicrosoftStringFunctions();
+
+    /**
+      * Remove Borland code
+      */
     void simplifyBorland();
 
     /**
@@ -637,7 +672,7 @@ public:
      */
     void duplicateEnumError(const Token *tok1, const Token *tok2, const std::string & type);
 
-    bool duplicateTypedef(Token **tokPtr, const Token *name, const Token *typeDef);
+    bool duplicateTypedef(Token **tokPtr, const Token *name, const Token *typeDef, bool undefinedStruct);
     void duplicateTypedefError(const Token *tok1, const Token *tok2, const std::string & type);
 
     /**
@@ -677,6 +712,11 @@ public:
      */
     void simplifyReturn();
 
+    /**
+     * Output list of unknown types.
+     */
+    void printUnknownTypes();
+
 private:
     /** Disable copy constructor, no implementation */
     Tokenizer(const Tokenizer &);
