@@ -60,6 +60,8 @@ private:
         TEST_CASE(includes2);
         TEST_CASE(enabledAll);
         TEST_CASE(enabledStyle);
+        TEST_CASE(enabledPerformance);
+        TEST_CASE(enabledPortability);
         TEST_CASE(enabledUnusedFunction);
         TEST_CASE(enabledMissingInclude);
         TEST_CASE(errorExitcode);
@@ -69,16 +71,21 @@ private:
         TEST_CASE(exitcodeSuppressions);
         TEST_CASE(exitcodeSuppressionsNoFile);
         TEST_CASE(fileList); // TODO: Create and test real file listing file
+        // TEST_CASE(fileListStdin);  // Disabled since hangs the test run
         TEST_CASE(inlineSuppr);
         TEST_CASE(jobs);
         TEST_CASE(jobsMissingCount);
         TEST_CASE(jobsInvalid);
-        TEST_CASE(reportProgress);
+        TEST_CASE(reportProgressTest); // "Test" suffix to avoid hiding the parent's reportProgress
+        TEST_CASE(stdposix);
+        TEST_CASE(stdc99);
         TEST_CASE(suppressionsOld); // TODO: Create and test real suppression file
         TEST_CASE(suppressions);
         TEST_CASE(suppressionsNoFile);
         TEST_CASE(suppressionSingle);
         TEST_CASE(suppressionSingleFile);
+        TEST_CASE(suppressionTwo);
+        TEST_CASE(suppressionTwoSeparate);
         TEST_CASE(templates);
         TEST_CASE(templatesGcc);
         TEST_CASE(templatesVs);
@@ -402,6 +409,38 @@ private:
         CmdLineParser parser(&settings);
         ASSERT(parser.ParseFromArgs(3, argv));
         ASSERT(settings.isEnabled("style"));
+        ASSERT(settings.isEnabled("performance"));
+        ASSERT(settings.isEnabled("portability"));
+        ASSERT(!settings.isEnabled("unusedFunction"));
+        ASSERT(!settings.isEnabled("missingInclude"));
+    }
+
+    void enabledPerformance()
+    {
+        REDIRECT;
+        const char *argv[] = {"cppcheck", "--enable=performance", "file.cpp"};
+        Settings settings;
+        CmdLineParser parser(&settings);
+        ASSERT(parser.ParseFromArgs(3, argv));
+        ASSERT(!settings.isEnabled("style"));
+        ASSERT(settings.isEnabled("performance"));
+        ASSERT(!settings.isEnabled("portability"));
+        ASSERT(!settings.isEnabled("unusedFunction"));
+        ASSERT(!settings.isEnabled("missingInclude"));
+    }
+
+    void enabledPortability()
+    {
+        REDIRECT;
+        const char *argv[] = {"cppcheck", "--enable=portability", "file.cpp"};
+        Settings settings;
+        CmdLineParser parser(&settings);
+        ASSERT(parser.ParseFromArgs(3, argv));
+        ASSERT(!settings.isEnabled("style"));
+        ASSERT(!settings.isEnabled("performance"));
+        ASSERT(settings.isEnabled("portability"));
+        ASSERT(!settings.isEnabled("unusedFunction"));
+        ASSERT(!settings.isEnabled("missingInclude"));
     }
 
     void enabledUnusedFunction()
@@ -494,6 +533,17 @@ private:
         TODO_ASSERT_EQUALS(true, false, parser.ParseFromArgs(4, argv));
     }
 
+    void fileListStdin()
+    {
+        // TODO: Give it some stdin to read from, fails because the list of
+        // files in stdin (_pathnames) is empty
+        REDIRECT;
+        const char *argv[] = {"cppcheck", "--file-list=-", "file.cpp"};
+        Settings settings;
+        CmdLineParser parser(&settings);
+        TODO_ASSERT_EQUALS(true, false, parser.ParseFromArgs(3, argv));
+    }
+
     void inlineSuppr()
     {
         REDIRECT;
@@ -533,7 +583,7 @@ private:
         ASSERT_EQUALS(false, parser.ParseFromArgs(4, argv));
     }
 
-    void reportProgress()
+    void reportProgressTest()
     {
         REDIRECT;
         const char *argv[] = {"cppcheck", "--report-progress", "file.cpp"};
@@ -543,6 +593,26 @@ private:
         ASSERT(settings.reportProgress);
     }
 
+    void stdposix()
+    {
+        REDIRECT;
+        const char *argv[] = {"cppcheck", "--std=posix", "file.cpp"};
+        Settings settings;
+        CmdLineParser parser(&settings);
+        ASSERT(parser.ParseFromArgs(3, argv));
+        ASSERT(settings.posix);
+    }
+
+    void stdc99()
+    {
+        REDIRECT;
+        const char *argv[] = {"cppcheck", "--std=c99", "file.cpp"};
+        Settings settings;
+        CmdLineParser parser(&settings);
+        ASSERT(parser.ParseFromArgs(3, argv));
+        ASSERT(settings.c99);
+    }
+
     void suppressionsOld()
     {
         // TODO: Fails because there is no suppr.txt file!
@@ -593,6 +663,28 @@ private:
         ASSERT_EQUALS(true, settings.nomsg.isSuppressed("uninitvar", "file.cpp", 1U));
     }
 
+    void suppressionTwo()
+    {
+        REDIRECT;
+        const char *argv[] = {"cppcheck", "--suppress=uninitvar,unnecessaryQualification", "file.cpp"};
+        Settings settings;
+        CmdLineParser parser(&settings);
+        TODO_ASSERT_EQUALS(true, false, parser.ParseFromArgs(3, argv));
+        TODO_ASSERT_EQUALS(true, false, settings.nomsg.isSuppressed("uninitvar", "file.cpp", 1U));
+        TODO_ASSERT_EQUALS(true, false, settings.nomsg.isSuppressed("unnecessaryQualification", "file.cpp", 1U));
+    }
+
+    void suppressionTwoSeparate()
+    {
+        REDIRECT;
+        const char *argv[] = {"cppcheck", "--suppress=uninitvar", "--suppress=unnecessaryQualification", "file.cpp"};
+        Settings settings;
+        CmdLineParser parser(&settings);
+        ASSERT(parser.ParseFromArgs(4, argv));
+        ASSERT_EQUALS(true, settings.nomsg.isSuppressed("uninitvar", "file.cpp", 1U));
+        ASSERT_EQUALS(true, settings.nomsg.isSuppressed("unnecessaryQualification", "file.cpp", 1U));
+    }
+
     void templates()
     {
         REDIRECT;
