@@ -385,6 +385,13 @@ private:
               "    }\n"
               "}");
         ASSERT_EQUALS("", errout.str());
+
+        // #3128
+        check("void f(ABC *abc) {\n"
+              "    x(!abc || y(abc->a));\n"
+              "    if (abc) {}\n"
+              "}");
+        ASSERT_EQUALS("", errout.str());
     }
 
     // Dereferencing a pointer and then checking if it is null
@@ -481,6 +488,31 @@ private:
               "}\n");
         ASSERT_EQUALS("", errout.str());
 
+        check("void foo(int *p)\n"
+              "{\n"
+              "    int var1 = x ? *p : 5;\n"
+              "    if (!p)\n"
+              "        ;\n"
+              "}\n");
+        TODO_ASSERT_EQUALS("error", "", errout.str());
+
+        // Ticket #3125
+        check("void foo(ABC *p)\n"
+              "{\n"
+              "    int var1 = p ? (p->a) : 0;\n"
+              "    if (!p)\n"
+              "        ;\n"
+              "}\n");
+        ASSERT_EQUALS("", errout.str());
+
+        check("void foo(ABC *p)\n"
+              "{\n"
+              "    int var1 = p ? (1 + p->a) : 0;\n"
+              "    if (!p)\n"
+              "        ;\n"
+              "}\n");
+        ASSERT_EQUALS("", errout.str());
+
         check("void foo(P *p)\n"
               "{\n"
               "  while (p)\n"
@@ -499,6 +531,19 @@ private:
               "}");
         ASSERT_EQUALS("", errout.str());
 
+        // #3128 - false positive
+        check("void f(int *p) {\n"
+              "    assert(!p || (*p<=6));\n"
+              "    if (p) { *p = 0; }\n"
+              "}");
+        ASSERT_EQUALS("", errout.str());
+
+        check("void f(int *p) {\n"
+              "    assert(p && (*p<=6));\n"
+              "    if (p) { *p = 0; }\n"
+              "}");
+        ASSERT_EQUALS("", errout.str());
+
         check("void foo(x *p)\n"
               "{\n"
               "    p = p->next;\n"
@@ -584,6 +629,18 @@ private:
               "        ;\n"
               "}\n");
         ASSERT_EQUALS("", errout.str());
+
+        // #3023 - checked deref
+        check("void f(struct ABC *abc) {\n"
+              "  WARN_ON(!abc || abc->x == 0);\n"
+              "  if (!abc) { }\n"
+              "}");
+        ASSERT_EQUALS("", errout.str());
+        check("void f(struct ABC *abc) {\n"
+              "  WARN_ON(!abc || abc->x == 7);\n"
+              "  if (!abc) { }\n"
+              "}");
+        ASSERT_EQUALS("", errout.str());
     }
 
     void nullpointer5()
@@ -1050,6 +1107,14 @@ private:
               "}\n");
         ASSERT_EQUALS("", errout.str());
 
+        check("void foo(char *p) {\n"
+              "    if (!p) {\n"
+              "        ab.abort();\n"
+              "    }\n"
+              "    *p = 0;\n"
+              "}\n");
+        ASSERT_EQUALS("", errout.str());
+
         check("void foo(char *p) {\n"
               "    if (!p) {\n"
               "        switch (x) { }\n"
@@ -1230,6 +1295,11 @@ private:
               "}\n");
         ASSERT_EQUALS("", errout.str());
 
+        // Ticket #3126 - don't confuse member function with standard function
+        check("void f() {\n"
+              "    image1.fseek(0, SEEK_SET);\n"
+              "}");
+        ASSERT_EQUALS("", errout.str());
     }
 
     void gcc_statement_expression()
