@@ -48,6 +48,11 @@ private:
 
         // dangerous function
         TEST_CASE(testgets);
+
+        TEST_CASE(testalloca);
+
+        // declared function ticket #3121
+        TEST_CASE(test_declared_function);
     }
 
     void check(const char code[])
@@ -58,6 +63,7 @@ private:
         Settings settings;
         settings.addEnabled("style");
         settings.posix = true;
+        settings.c99 = true;
 
         // Tokenize..
         Tokenizer tokenizer(&settings, this);
@@ -82,7 +88,7 @@ private:
               "{\n"
               "    bsd_signal(SIGABRT, SIG_IGN);\n"
               "}\n");
-        ASSERT_EQUALS("[test.cpp:3]: (information) Found obsolete function 'bsd_signal'. It is recommended that new applications use the 'sigaction' function\n", errout.str());
+        ASSERT_EQUALS("[test.cpp:3]: (style) Found obsolete function 'bsd_signal'. It is recommended that new applications use the 'sigaction' function\n", errout.str());
 
         check("int f()\n"
               "{\n"
@@ -102,7 +108,7 @@ private:
               "        exit(1);\n"
               "    }\n"
               "}\n");
-        ASSERT_EQUALS("[test.cpp:4]: (information) Found obsolete function 'gethostbyname'. It is recommended that new applications use the 'getaddrinfo' function\n", errout.str());
+        ASSERT_EQUALS("[test.cpp:4]: (style) Found obsolete function 'gethostbyname'. It is recommended that new applications use the 'getaddrinfo' function\n", errout.str());
     }
 
     void testgethostbyaddr()
@@ -115,7 +121,7 @@ private:
               "        exit(1);\n"
               "    }\n"
               "}\n");
-        ASSERT_EQUALS("[test.cpp:5]: (information) Found obsolete function 'gethostbyaddr'. It is recommended that new applications use the 'getnameinfo' function\n", errout.str());
+        ASSERT_EQUALS("[test.cpp:5]: (style) Found obsolete function 'gethostbyaddr'. It is recommended that new applications use the 'getnameinfo' function\n", errout.str());
     }
 
     void testusleep()
@@ -124,7 +130,7 @@ private:
               "{\n"
               "    usleep( 1000 );\n"
               "}\n");
-        ASSERT_EQUALS("[test.cpp:3]: (information) Found obsolete function 'usleep'. It is recommended that new applications use the 'nanosleep' or 'setitimer' function\n", errout.str());
+        ASSERT_EQUALS("[test.cpp:3]: (style) Found obsolete function 'usleep'. It is recommended that new applications use the 'nanosleep' or 'setitimer' function\n", errout.str());
     }
 
     void testindex()
@@ -165,7 +171,7 @@ private:
               "    const char i = index(var, 0);\n"
               "    return i;\n"
               "}\n");
-        ASSERT_EQUALS("[test.cpp:4]: (information) Found obsolete function 'index'. It is recommended to use the function 'strchr' instead\n",
+        ASSERT_EQUALS("[test.cpp:4]: (style) Found obsolete function 'index'. It is recommended to use the function 'strchr' instead\n",
                       errout.str());
     }
 
@@ -174,7 +180,7 @@ private:
         check("void TDataModel::forceRowRefresh(int row) {\n"
               "    emit dataChanged(index(row, 0), index(row, columnCount() - 1));\n"
               "}\n");
-        ASSERT_EQUALS("[test.cpp:2]: (information) Found obsolete function 'index'. It is recommended to use the function 'strchr' instead\n", errout.str());
+        ASSERT_EQUALS("[test.cpp:2]: (style) Found obsolete function 'index'. It is recommended to use the function 'strchr' instead\n", errout.str());
     }
 
     void testrindex()
@@ -190,7 +196,7 @@ private:
               "    const char var[7] = 'rindex';\n"
               "    print(rindex(var, 0));\n"
               "}\n");
-        ASSERT_EQUALS("[test.cpp:4]: (information) Found obsolete function 'rindex'. It is recommended to use the function 'strrchr' instead\n", errout.str());
+        ASSERT_EQUALS("[test.cpp:4]: (style) Found obsolete function 'rindex'. It is recommended to use the function 'strrchr' instead\n", errout.str());
     }
 
 
@@ -210,11 +216,32 @@ private:
               "{\n"
               "    char *x = gets();\n"
               "}\n");
-        ASSERT_EQUALS("[test.cpp:3]: (information) Found obsolete function 'gets'. It is recommended to use the function 'fgets' instead\n", errout.str());
+        ASSERT_EQUALS("[test.cpp:3]: (style) Found obsolete function 'gets'. It is recommended to use the function 'fgets' instead\n", errout.str());
     }
 
+    void testalloca()
+    {
+        check("void f()\n"
+              "{\n"
+              "    char *x = alloca(10);\n"
+              "}\n");
+        ASSERT_EQUALS("[test.cpp:3]: (style) Found obsolete function 'alloca'. It is recommended to use a variable length array.\n", errout.str());
+    }
 
-
+    // ticket #3121
+    void test_declared_function()
+    {
+        check("ftime ( int a )\n"
+              "{\n"
+              "    return a;\n"
+              "}\n"
+              "int main ()\n"
+              "{\n"
+              "    int b ; b = ftime ( 1 ) ;\n"
+              "    return 0 ;\n"
+              "}\n");
+        ASSERT_EQUALS("", errout.str());
+    }
 };
 
 REGISTER_TEST(TestObsoleteFunctions)
