@@ -41,6 +41,11 @@ public:
         ,isArray(false)
     {}
 
+    virtual void reportOut(const std::string &outmsg)
+    {
+        errout << outmsg << std::endl;
+    }
+
 private:
     const Scope si;
     const Token* vartok;
@@ -102,6 +107,7 @@ private:
         TEST_CASE(hasGlobalVariables3);
 
         TEST_CASE(functionArgs1);
+        TEST_CASE(functionArgs2);
 
         TEST_CASE(symboldatabase1);
         TEST_CASE(symboldatabase2);
@@ -122,6 +128,8 @@ private:
         TEST_CASE(symboldatabase17); // ticket #2657
         TEST_CASE(symboldatabase18); // ticket #2865
         TEST_CASE(symboldatabase19); // ticket #2991 (segmentation fault)
+        TEST_CASE(symboldatabase20); // ticket #3013 (segmentation fault)
+        TEST_CASE(symboldatabase21);
     }
 
     void test_isVariableDeclarationCanHandleNull()
@@ -627,14 +635,14 @@ private:
         }
     }
 
-    void check(const char code[])
+    void check(const char code[], bool debug = true)
     {
         // Clear the error log
         errout.str("");
 
         // Check..
         Settings settings;
-        settings.debugwarnings = true;
+        settings.debugwarnings = debug;
 
         // Tokenize..
         Tokenizer tokenizer(&settings, this);
@@ -657,6 +665,16 @@ private:
         ASSERT_EQUALS("", errout.str());
     }
 
+    void functionArgs2()
+    {
+        GET_SYMBOL_DB("void f(int a[][4]) { }");
+        const Variable *a = db->getVariableFromVarId(1);
+        ASSERT_EQUALS("a", a->nameToken()->str());
+        ASSERT_EQUALS(2UL, a->dimensions().size());
+        ASSERT_EQUALS(0UL, a->dimension(0));
+        ASSERT_EQUALS(4UL, a->dimension(1));
+    }
+
     void symboldatabase1()
     {
         check("namespace foo {\n"
@@ -744,7 +762,7 @@ private:
               "template<class T> class Y { };\n"
               "Y<X<1>> x3;\n"
               "Y<X<6>>1>> x4;\n"
-              "Y<X<(6>>1)>> x5;\n");
+              "Y<X<(6>>1)>> x5;\n", false);
         ASSERT_EQUALS("", errout.str());
     }
 
@@ -789,7 +807,7 @@ private:
               "        CString::operator=(lpsz);\n"
               "        return *this;\n"
               "    }\n"
-              "};\n");
+              "};\n", false);
 
         ASSERT_EQUALS("", errout.str());
     }
@@ -887,6 +905,27 @@ private:
         ASSERT_EQUALS("", errout.str());
     }
 
+    void symboldatabase20()
+    {
+        // ticket #3013 - segmentation fault
+        check("struct x : virtual y\n");
+
+        ASSERT_EQUALS("", errout.str());
+    }
+
+    void symboldatabase21()
+    {
+        check("class Fred {\n"
+              "    class Foo { };\n"
+              "    void func() const;\n"
+              "};\n"
+              "Fred::func() const {\n"
+              "    Foo foo;\n"
+              "}\n");
+
+        ASSERT_EQUALS("", errout.str());
+    }
+
 };
 
 REGISTER_TEST(TestSymbolDatabase)
