@@ -45,6 +45,7 @@ private:
         TEST_CASE(uninitvar_switch);    // handling switch
         TEST_CASE(uninitvar_references); // references
         TEST_CASE(uninitvar_strncpy);   // strncpy doesn't always 0-terminate
+        TEST_CASE(uninitvar_memset);    // not 0-terminated
         TEST_CASE(uninitvar_func);      // analyse functions
         TEST_CASE(func_uninit_var);     // analyse function calls for: 'int a(int x) { return x+x; }'
         TEST_CASE(func_uninit_pointer); // analyse function calls for: 'void a(int *p) { *p = 0; }'
@@ -84,6 +85,18 @@ private:
                        "}\n");
         ASSERT_EQUALS("[test.cpp:3]: (error) Uninitialized variable: a\n", errout.str());
 
+        checkUninitVar("void foo() {\n"
+                       "    int *p;\n"
+                       "    realloc(p,10);\n"
+                       "}\n");
+        ASSERT_EQUALS("[test.cpp:3]: (error) Uninitialized variable: p\n", errout.str());
+
+        checkUninitVar("void foo() {\n"
+                       "    int *p = NULL;\n"
+                       "    realloc(p,10);\n"
+                       "}\n");
+        ASSERT_EQUALS("", errout.str());
+
         // dereferencing uninitialized pointer..
         checkUninitVar("static void foo()\n"
                        "{\n"
@@ -155,6 +168,13 @@ private:
                        "}\n");
         ASSERT_EQUALS("", errout.str());
 
+        checkUninitVar("void foo()\n"
+                       "{\n"
+                       "    int *x;\n"
+                       "    int *&y = x;\n"
+                       "}\n");
+        ASSERT_EQUALS("", errout.str());
+
         checkUninitVar("void foo()\n"
                        "{\n"
                        "    int x = xyz::x;\n"
@@ -315,6 +335,13 @@ private:
                        "}\n");
         ASSERT_EQUALS("", errout.str());
 
+        checkUninitVar("int a(FArchive &arc) {\n"   // #3060 (initialization through operator<<)
+                       "    int *p;\n"
+                       "    arc << p;\n"
+                       "    return *p;\n"
+                       "}\n");
+        ASSERT_EQUALS("", errout.str());
+
         checkUninitVar("int a()\n"
                        "{\n"
                        "    int ret;\n"
@@ -486,6 +513,20 @@ private:
                        "    return x ? 1 : y;\n"
                        "}\n");
         ASSERT_EQUALS("[test.cpp:2]: (error) Uninitialized variable: y\n", errout.str());
+
+        // Ticket #3106 - False positive
+        checkUninitVar("int f() {\n"
+                       "    int i;\n"
+                       "    return x(&i) ? i : 0;\n"
+                       "}\n");
+        ASSERT_EQUALS("", errout.str());
+
+        // Ticket #3106 - False negative
+        checkUninitVar("int f() {\n"
+                       "    int i;\n"
+                       "    return x() ? i : 0;\n"
+                       "}\n");
+        TODO_ASSERT_EQUALS("[test.cpp:2]: (error) Uninitialized variable: i\n", "", errout.str());
     }
 
 
@@ -1060,6 +1101,12 @@ private:
                        "        char *b = (a+2) & 7;\n"
                        "}\n");
         ASSERT_EQUALS("", errout.str());
+
+        checkUninitVar("void f() {\n"   // Ticket #3050
+                       "    char a[2];\n"
+                       "    printf(\"%s\", a);\n"
+                       "}");
+        ASSERT_EQUALS("[test.cpp:3]: (error) Uninitialized variable: a\n", errout.str());
     }
 
     // alloc..
@@ -1299,6 +1346,16 @@ private:
         ASSERT_EQUALS("", errout.str());
     }
 
+    // initialization with memset (not 0-terminating string)..
+    void uninitvar_memset()
+    {
+        checkUninitVar("void f() {\n"
+                       "    char a[20];\n"
+                       "    memset(a, 'a', 20);\n"
+                       "    strcat(a, s);\n"
+                       "}\n");
+        ASSERT_EQUALS("[test.cpp:4]: (error) Dangerous usage of 'a' (not 0-terminated)\n", errout.str());
+    }
 
     std::string analyseFunctions(const char code[])
     {
@@ -1511,6 +1568,19 @@ private:
                        "    buf[1] = buf[0];\n"
                        "}");
         ASSERT_EQUALS("", errout.str());
+
+        // #3159 - initialization by function
+        checkUninitVar("static int isnumber(const char *arg) {\n"
+                       "    char *p;\n"
+                       "    return strtod(arg, &p) != 0 || p != arg;\n"
+                       "}");
+        ASSERT_EQUALS("", errout.str());
+
+        checkUninitVar("static int isnumber(const char *arg) {\n"
+                       "    char *p;\n"
+                       "    return strtod(&arg) != 0 || p != arg;\n"
+                       "}");
+        TODO_ASSERT_EQUALS("error", "", errout.str());
     }
 
     // valid and invalid use of 'int a(int x) { return x + x; }'
