@@ -44,9 +44,12 @@ private:
         TEST_CASE(template1);
         TEST_CASE(throwIsNotAFunction);
         TEST_CASE(unusedError);
+        TEST_CASE(unusedMain);
         TEST_CASE(initializationIsNotAFunction);
 
         TEST_CASE(multipleFiles);   // same function name in multiple files
+
+        TEST_CASE(lineNumber); // Ticket 3059
     }
 
     void check(const char code[])
@@ -177,6 +180,18 @@ private:
         ASSERT_EQUALS("[test.cpp:1]: (style) The function 'foo' is never used\n", errout.str());
     }
 
+    void unusedMain()
+    {
+        check("int main() { }\n");
+        ASSERT_EQUALS("", errout.str());
+
+        check("int _tmain() { }\n");
+        ASSERT_EQUALS("", errout.str());
+
+        check("int WinMain() { }\n");
+        ASSERT_EQUALS("", errout.str());
+    }
+
     void initializationIsNotAFunction()
     {
         check("struct B: N::A {\n"
@@ -216,6 +231,15 @@ private:
 
         ASSERT_EQUALS("[test1.cpp:1]: (style) The function 'f' is never used\n",errout.str());
     }
+
+    void lineNumber()
+    {
+        check("void foo() {}\n"
+              "void bar() {}\n"
+              "int main()\n");
+        ASSERT_EQUALS("[test.cpp:2]: (style) The function 'bar' is never used\n"
+                      "[test.cpp:1]: (style) The function 'foo' is never used\n", errout.str());
+    }
 };
 
 REGISTER_TEST(TestUnusedFunctions)
