@@ -45,6 +45,7 @@ private:
         TEST_CASE(func_pointer1);
         TEST_CASE(func_pointer2);
         TEST_CASE(func_pointer3);
+        TEST_CASE(func_pointer4); // ticket #2807
 
         TEST_CASE(ctor);
 
@@ -78,7 +79,7 @@ private:
         errout.str("");
 
         Settings settings;
-        settings._checkCodingStyle = true;
+        settings.addEnabled("style");
 
         // Tokenize..
         Tokenizer tokenizer(&settings, this);
@@ -298,6 +299,21 @@ private:
     }
 
 
+    void func_pointer4() // ticket #2807
+    {
+        check("class myclass {\n"
+              "public:\n"
+              "    myclass();\n"
+              "private:\n"
+              "    static void f();\n"
+              "    void (*fptr)();\n"
+              "};\n"
+              "myclass::myclass() { fptr = &f; }\n"
+              "void myclass::f() {}\n");
+        ASSERT_EQUALS("", errout.str());
+    }
+
+
     void ctor()
     {
         check("class PrivateCtor\n"
