@@ -182,8 +182,8 @@ int main(int argc, char **argv)
         if (fout1.is_open())
         {
             fout1 << "# no manual edits - this file is autogenerated by dmake\n\n";
-            fout1 << "LIBS += -L../externals -lpcre\n";
-            fout1 << "INCLUDEPATH += ../externals ../externals/tinyxml\n";
+            fout1 << "include($$PWD/pcrerules.pri)\n";
+            fout1 << "INCLUDEPATH += ../externals/tinyxml\n";
             fout1 << "HEADERS += $${BASEPATH}check.h \\\n";
             for (unsigned int i = 0; i < libfiles.size(); ++i)
             {
@@ -218,8 +218,8 @@ int main(int argc, char **argv)
     }
 
     fout << "# This file is generated by tools/dmake, do not edit.\n\n";
-    fout << "# To compile without rules, use 'make HAVE_RULES=no'\n"
-         << "HAVE_RULES = yes\n\n";
+    fout << "# To compile without rules, use 'make HAVE_RULES=no'\n";
+    makeConditionalVariable(fout, "HAVE_RULES", "yes");
 
     // Makefile settings..
     if (release)
@@ -244,6 +244,7 @@ int main(int argc, char **argv)
                                 "-Wcast-qual "
 //                                "-Wsign-conversion "
 //                                "-Wconversion "
+                                "-D_GLIBCXX_DEBUG "
                                 "-g");
     }
 
